@@ -6,116 +6,134 @@
 extern void afsi_log(char *pattern, ...);
 extern DWORD cm_ValidateCache;
 
-DWORD
-GranularityAdjustment(DWORD size)
+afs_uint64
+GranularityAdjustment(afs_uint64 size)
 {
     SYSTEM_INFO sysInfo;
-    static DWORD dwGranularity = 0;
+    static afs_uint64 qwGranularity = 0;
 
-    if ( !dwGranularity ) {
+    if ( !qwGranularity ) {
         GetSystemInfo(&sysInfo);
         afsi_log("Granularity - %lX", sysInfo.dwAllocationGranularity);
-        dwGranularity = sysInfo.dwAllocationGranularity;
+        qwGranularity = sysInfo.dwAllocationGranularity;
     }
 
-    size = (size + (dwGranularity - 1)) & ~(dwGranularity - 1);
+    size = (size + (qwGranularity - 1)) & ~(qwGranularity - 1);
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfConfigData(void)
 {
-    DWORD size;
+    afs_uint64 size;
     size = sizeof(cm_config_data_t);
     return size;
 }
 
-DWORD
+afs_uint64
 ComputeSizeOfVolumes(DWORD maxvols)
 {
-    DWORD size;
+    afs_uint64 size;
     size = maxvols * sizeof(cm_volume_t);
     return size;
 }
 
-DWORD
+afs_uint64
+ComputeSizeOfCellHT(DWORD maxcells)
+{
+    afs_uint64 size;
+    size = osi_PrimeLessThan((afs_uint32)(maxcells/7 + 1)) * sizeof(cm_cell_t *);
+    return size;
+}
+
+afs_uint64
+ComputeSizeOfVolumeHT(DWORD maxvols)
+{
+    afs_uint64 size;
+    size = osi_PrimeLessThan((afs_uint32)(maxvols/7 + 1)) * sizeof(cm_volume_t *);
+    return size;
+}
+
+afs_uint64
 ComputeSizeOfCells(DWORD maxcells)
 {
-    DWORD size;
+    afs_uint64 size;
     size = maxcells * sizeof(cm_cell_t);
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfACLCache(DWORD stats)
 {
-    DWORD size;
+    afs_uint64 size;
     size = 2 * (stats + 10) * sizeof(cm_aclent_t);
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfSCache(DWORD stats)
 {
-    DWORD size;
+    afs_uint64 size;
     size = (stats + 10) * sizeof(cm_scache_t);
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfSCacheHT(DWORD stats)
 {
-    DWORD size;
-    size = (stats + 10) / 2 * sizeof(cm_scache_t *);;
+    afs_uint64 size;
+    size = osi_PrimeLessThan(stats / 2 + 1) * sizeof(cm_scache_t *);;
     return size;
 }
 
-DWORD 
+afs_uint64 
 ComputeSizeOfDNLCache(void)
 {
-    DWORD size;
+    afs_uint64 size;
     size = NHSIZE * sizeof(cm_nc_t *) + NCSIZE * sizeof(cm_nc_t);
     return size;
 }
 
-DWORD 
-ComputeSizeOfDataBuffers(DWORD cacheBlocks, DWORD blockSize)
+afs_uint64 
+ComputeSizeOfDataBuffers(afs_uint64 cacheBlocks, DWORD blockSize)
 {
-    DWORD size;
+    afs_uint64 size;
     size = cacheBlocks * blockSize;
     return size;
 }
 
-DWORD 
-ComputeSizeOfDataHT(void)
+afs_uint64 
+ComputeSizeOfDataHT(afs_uint64 cacheBlocks)
 {
-    DWORD size;
-    size = osi_PrimeLessThan(CM_BUF_HASHSIZE) * sizeof(cm_buf_t *);
+    afs_uint64 size;
+    size = osi_PrimeLessThan((afs_uint32)(cacheBlocks/7 + 1)) * sizeof(cm_buf_t *);
     return size;
 }
 
-DWORD 
-ComputeSizeOfDataHeaders(DWORD cacheBlocks)
+afs_uint64 
+ComputeSizeOfDataHeaders(afs_uint64 cacheBlocks)
 {
-    DWORD size;
+    afs_uint64 size;
     size = cacheBlocks * sizeof(cm_buf_t);
     return size;
 }
 
-DWORD
-ComputeSizeOfMappingFile(DWORD stats, DWORD maxVols, DWORD maxCells, DWORD chunkSize, DWORD cacheBlocks, DWORD blockSize)
+afs_uint64
+ComputeSizeOfMappingFile(DWORD stats, DWORD maxVols, DWORD maxCells, DWORD chunkSize, afs_uint64 cacheBlocks, DWORD blockSize)
 {
-    DWORD size;
+    afs_uint64 size;
     
     size       =  ComputeSizeOfConfigData()
                +  ComputeSizeOfVolumes(maxVols) 
+               +  4 * ComputeSizeOfVolumeHT(maxVols) 
                +  ComputeSizeOfCells(maxCells) 
+               +  2 * ComputeSizeOfCellHT(maxCells)
                +  ComputeSizeOfACLCache(stats)
                +  ComputeSizeOfSCache(stats)
                +  ComputeSizeOfSCacheHT(stats)
                +  ComputeSizeOfDNLCache()
                +  ComputeSizeOfDataBuffers(cacheBlocks, blockSize) 
-               +  2 * ComputeSizeOfDataHT() 
+               +  2 * ComputeSizeOfDataHT(cacheBlocks) 
                +  ComputeSizeOfDataHeaders(cacheBlocks);
     return size;    
 }
@@ -214,6 +232,23 @@ cm_ShutdownMappedMemory(void)
     cm_config_data_t * config_data_p = (cm_config_data_t *)cm_data.baseAddress;
     int dirty = 0;
 
+    afsi_log("Closing AFS Cache:");
+    afsi_log("  Base Address   = %p", config_data_p);
+    afsi_log("  stats          = %d", cm_data.stats);
+    afsi_log("  chunkSize      = %d", cm_data.chunkSize);
+    afsi_log("  blockSize      = %d", cm_data.blockSize);
+    afsi_log("  bufferSize     = %d", cm_data.bufferSize);
+    afsi_log("  cacheType      = %d", cm_data.cacheType);
+    afsi_log("  volumeHashTableSize = %d", cm_data.volumeHashTableSize);
+    afsi_log("  currentVolumes = %d", cm_data.currentVolumes);
+    afsi_log("  maxVolumes     = %d", cm_data.maxVolumes);
+    afsi_log("  cellHashTableSize = %d", cm_data.cellHashTableSize);
+    afsi_log("  currentCells   = %d", cm_data.currentCells);
+    afsi_log("  maxCells       = %d", cm_data.maxCells);
+    afsi_log("  scacheHashTableSize  = %d", cm_data.scacheHashTableSize);
+    afsi_log("  currentSCaches = %d", cm_data.currentSCaches);
+    afsi_log("  maxSCaches     = %d", cm_data.maxSCaches);
+
     cm_ShutdownDCache();
     cm_ShutdownSCache();
     cm_ShutdownACLCache();
@@ -230,6 +265,7 @@ cm_ShutdownMappedMemory(void)
     hMemoryMappedFile = NULL;
 
     afsi_log("Memory Mapped File has been closed");
+    return 0;
 }
 
 int
@@ -239,7 +275,7 @@ cm_ValidateMappedMemory(char * cachePath)
     PSECURITY_ATTRIBUTES psa;
     BY_HANDLE_FILE_INFORMATION fileInfo;
     int newFile = 1;
-    DWORD mappingSize;
+    afs_uint64 mappingSize;
     char * baseAddress = NULL;
     cm_config_data_t * config_data_p;
         
@@ -338,7 +374,8 @@ cm_ValidateMappedMemory(char * cachePath)
     hm = CreateFileMapping( hf,
                             NULL,
                             PAGE_READWRITE,
-                            0, mappingSize,
+			    (DWORD)(mappingSize >> 32), 
+			    (DWORD)(mappingSize & 0xFFFFFFFF),
                             NULL);
     if (hm == NULL) {
         if (GetLastError() == ERROR_DISK_FULL) {
@@ -355,15 +392,15 @@ cm_ValidateMappedMemory(char * cachePath)
     
     baseAddress = MapViewOfFileEx( hm,
                                    FILE_MAP_ALL_ACCESS,
-                                   0, 0,   
-                                   mappingSize,
+                                   0, 0,
+				   (SIZE_T)mappingSize,
                                    baseAddress );
     if (baseAddress == NULL) {
         fprintf(stderr, "Error mapping view of file: %d\n", GetLastError());
         baseAddress = MapViewOfFile( hm,
                                      FILE_MAP_ALL_ACCESS,
-                                     0, 0,   
-                                     mappingSize );
+                                     0, 0,
+				     (SIZE_T)mappingSize);
         if (baseAddress == NULL) {
             CloseHandle(hm);
             if (hf != INVALID_HANDLE_VALUE)
@@ -381,17 +418,19 @@ cm_ValidateMappedMemory(char * cachePath)
     config_data_p = (cm_config_data_t *) baseAddress;
 
     fprintf(stderr,"AFS Cache data:\n");
-    fprintf(stderr,"  Base Address   = %lX\n",baseAddress);
+    fprintf(stderr,"  Base Address   = %p\n",baseAddress);
     fprintf(stderr,"  stats          = %d\n", config_data_p->stats);
     fprintf(stderr,"  chunkSize      = %d\n", config_data_p->chunkSize);
     fprintf(stderr,"  blockSize      = %d\n", config_data_p->blockSize);
     fprintf(stderr,"  bufferSize     = %d\n", config_data_p->bufferSize);
     fprintf(stderr,"  cacheType      = %d\n", config_data_p->cacheType);
+    fprintf(stderr,"  volumeHashTableSize = %d", config_data_p->volumeHashTableSize);
     fprintf(stderr,"  currentVolumes = %d\n", config_data_p->currentVolumes);
     fprintf(stderr,"  maxVolumes     = %d\n", config_data_p->maxVolumes);
+    fprintf(stderr,"  cellHashTableSize = %d", config_data_p->cellHashTableSize);
     fprintf(stderr,"  currentCells   = %d\n", config_data_p->currentCells);
     fprintf(stderr,"  maxCells       = %d\n", config_data_p->maxCells);
-    fprintf(stderr,"  hashTableSize  = %d\n", config_data_p->hashTableSize );
+    fprintf(stderr,"  scacheHashTableSize  = %d\n", config_data_p->scacheHashTableSize);
     fprintf(stderr,"  currentSCaches = %d\n", config_data_p->currentSCaches);
     fprintf(stderr,"  maxSCaches     = %d\n", config_data_p->maxSCaches);
     cm_data = *config_data_p;      
@@ -583,12 +622,13 @@ GetMachineSid(PBYTE SidBuffer, DWORD SidSize)
 }
 
 int
-cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chunkSize, DWORD cacheBlocks)
+cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chunkSize, 
+                    afs_uint64 cacheBlocks, afs_uint32 blockSize)
 {
     HANDLE hf = INVALID_HANDLE_VALUE, hm;
     PSECURITY_ATTRIBUTES psa;
     int newFile = 1;
-    DWORD mappingSize;
+    afs_uint64 mappingSize;
     DWORD maxVols = stats/2;
     DWORD maxCells = stats/4;
     DWORD volumeSerialNumber = 0;
@@ -602,7 +642,7 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
     volumeSerialNumber = GetVolSerialNumber(cachePath);
     GetMachineSid(machineSid, sizeof(machineSid));
 
-    mappingSize = ComputeSizeOfMappingFile(stats, maxVols, maxCells, chunkSize, cacheBlocks, CM_CONFIGDEFAULT_BLOCKSIZE);
+    mappingSize = ComputeSizeOfMappingFile(stats, maxVols, maxCells, chunkSize, cacheBlocks, blockSize);
 
     if ( !virtualCache ) {
         psa = CreateCacheFileSA();
@@ -629,10 +669,14 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
             afsi_log("Cache File \"%s\" already exists", cachePath);
 
             if ( GetFileInformationByHandle(hf, &fileInfo) ) {
+		afs_uint64 filesize;
                 afsi_log("Existing File Size: %08X:%08X",
                           fileInfo.nFileSizeHigh,
                           fileInfo.nFileSizeLow);
-                if (fileInfo.nFileSizeLow > GranularityAdjustment(mappingSize)) {
+		filesize = fileInfo.nFileSizeHigh;
+		filesize <<= 32;
+		filesize += fileInfo.nFileSizeLow;
+                if (filesize > GranularityAdjustment(mappingSize)) {
                     psa = CreateCacheFileSA();
                     hf = CreateFile( cachePath,
                                      GENERIC_READ | GENERIC_WRITE,
@@ -655,7 +699,6 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
                               fileInfo.nFileSizeHigh,
                               fileInfo.nFileSizeLow);
                 }
-
             }
 
             hm = CreateFileMapping( hf,
@@ -672,8 +715,8 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
                     hm = CreateFileMapping( hf,
                                             NULL,
                                             PAGE_READWRITE,
-                                            0, 
-                                            mappingSize,
+                                            (DWORD)(mappingSize >> 32), 
+                                            (DWORD)(mappingSize & 0xFFFFFFFF),
                                             NULL);
                     if (hm == NULL) {
                         if (GetLastError() == ERROR_DISK_FULL) {
@@ -714,7 +757,7 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
                  config_data_p->maxCells == maxCells &&
                  config_data_p->chunkSize == chunkSize &&
                  config_data_p->buf_nbuffers == cacheBlocks &&
-                 config_data_p->blockSize == CM_CONFIGDEFAULT_BLOCKSIZE &&
+                 config_data_p->blockSize == blockSize &&
                  config_data_p->bufferSize == mappingSize)
             {
                 if ( config_data_p->dirty ) {
@@ -734,7 +777,8 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
     hm = CreateFileMapping( hf,
                             NULL,
                             PAGE_READWRITE,
-                            0, mappingSize,
+			    (DWORD)(mappingSize >> 32), 
+			    (DWORD)(mappingSize & 0xFFFFFFFF),
                             NULL);
     if (hm == NULL) {
         if (GetLastError() == ERROR_DISK_FULL) {
@@ -748,15 +792,17 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
     }
     baseAddress = MapViewOfFileEx( hm,
                                    FILE_MAP_ALL_ACCESS,
-                                   0, 0,   
-                                   mappingSize,
+                                   0, 
+				   0, 
+				   (SIZE_T)mappingSize,
                                    baseAddress );
     if (baseAddress == NULL) {
         afsi_log("Error mapping view of file: %d", GetLastError());
         baseAddress = MapViewOfFile( hm,
                                      FILE_MAP_ALL_ACCESS,
-                                     0, 0,   
-                                     mappingSize );
+                                     0, 
+				     0, 
+				     (SIZE_T)mappingSize);
         if (baseAddress == NULL) {
             if (hf != INVALID_HANDLE_VALUE)
                 CloseHandle(hf);
@@ -770,9 +816,25 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
     config_data_p = (cm_config_data_t *) baseAddress;
 
     if (!newFile) {
-        afsi_log("Reusing existing AFS Cache data: Base Address = %lX",baseAddress);
+        afsi_log("Reusing existing AFS Cache data:");
         cm_data = *config_data_p;      
 
+	afsi_log("  Base Address   = %p",baseAddress);
+	afsi_log("  stats          = %d", config_data_p->stats);
+	afsi_log("  chunkSize      = %d", config_data_p->chunkSize);
+	afsi_log("  blockSize      = %d", config_data_p->blockSize);
+	afsi_log("  bufferSize     = %d", config_data_p->bufferSize);
+	afsi_log("  cacheType      = %d", config_data_p->cacheType);
+	afsi_log("  volumeHashTableSize  = %d", config_data_p->volumeHashTableSize);
+	afsi_log("  currentVolumes = %d", config_data_p->currentVolumes);
+	afsi_log("  maxVolumes     = %d", config_data_p->maxVolumes);
+        afsi_log("  cellHashTableSize = %d", config_data_p->cellHashTableSize);
+	afsi_log("  currentCells   = %d", config_data_p->currentCells);
+	afsi_log("  maxCells       = %d", config_data_p->maxCells);
+	afsi_log("  scacheHashTableSize  = %d", config_data_p->scacheHashTableSize);
+	afsi_log("  currentSCaches = %d", config_data_p->currentSCaches);
+	afsi_log("  maxSCaches     = %d", config_data_p->maxSCaches);
+
         // perform validation of persisted data structures
         // if there is a failure, start from scratch
         if (cm_ValidateCache && !cm_IsCacheValid()) {
@@ -782,14 +844,17 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
 
     if ( newFile ) {
         afsi_log("Building AFS Cache from scratch");
+	memset(&cm_data, 0, sizeof(cm_config_data_t));
         cm_data.size = sizeof(cm_config_data_t);
         cm_data.magic = CM_CONFIG_DATA_MAGIC;
         cm_data.baseAddress = baseAddress;
         cm_data.stats = stats;
         cm_data.chunkSize = chunkSize;
-        cm_data.blockSize = CM_CONFIGDEFAULT_BLOCKSIZE;
+        cm_data.blockSize = blockSize;
         cm_data.bufferSize = mappingSize;
-        cm_data.hashTableSize = osi_PrimeLessThan(stats / 2 + 1);
+        cm_data.scacheHashTableSize = osi_PrimeLessThan(stats / 2 + 1);
+        cm_data.volumeHashTableSize = osi_PrimeLessThan((afs_uint32)(maxVols/7 + 1));
+        cm_data.cellHashTableSize = osi_PrimeLessThan((afs_uint32)(maxCells/7 + 1));
         if (virtualCache) {
             cm_data.cacheType = CM_BUF_CACHETYPE_VIRTUAL;
         } else {
@@ -798,33 +863,47 @@ cm_InitMappedMemory(DWORD virtualCache, char * cachePath, DWORD stats, DWORD chu
 
         cm_data.buf_nbuffers = cacheBlocks;
         cm_data.buf_nOrigBuffers = 0;
-        cm_data.buf_blockSize = CM_BUF_BLOCKSIZE;
-        cm_data.buf_hashSize = CM_BUF_HASHSIZE;
+        cm_data.buf_blockSize = blockSize;
+        cm_data.buf_hashSize = osi_PrimeLessThan((afs_uint32)(cacheBlocks/7 + 1));
 
         cm_data.mountRootGen = time(NULL);
 
         baseAddress += ComputeSizeOfConfigData();
         cm_data.volumeBaseAddress = (cm_volume_t *) baseAddress;
         baseAddress += ComputeSizeOfVolumes(maxVols);
+        cm_data.volumeNameHashTablep = (cm_volume_t **)baseAddress;
+        baseAddress += ComputeSizeOfVolumeHT(maxVols);
+        cm_data.volumeRWIDHashTablep = (cm_volume_t **)baseAddress;
+        baseAddress += ComputeSizeOfVolumeHT(maxVols);
+        cm_data.volumeROIDHashTablep = (cm_volume_t **)baseAddress;
+        baseAddress += ComputeSizeOfVolumeHT(maxVols);
+        cm_data.volumeBKIDHashTablep = (cm_volume_t **)baseAddress;
+        baseAddress += ComputeSizeOfVolumeHT(maxVols);
+        cm_data.cellNameHashTablep = (cm_cell_t **)baseAddress;
+        baseAddress += ComputeSizeOfCellHT(maxCells);
+        cm_data.cellIDHashTablep = (cm_cell_t **)baseAddress;
+        baseAddress += ComputeSizeOfCellHT(maxCells);
         cm_data.cellBaseAddress = (cm_cell_t *) baseAddress;
         baseAddress += ComputeSizeOfCells(maxCells);
         cm_data.aclBaseAddress = (cm_aclent_t *) baseAddress;
         baseAddress += ComputeSizeOfACLCache(stats);
         cm_data.scacheBaseAddress = (cm_scache_t *) baseAddress;
         baseAddress += ComputeSizeOfSCache(stats);
-        cm_data.hashTablep = (cm_scache_t **) baseAddress;
+        cm_data.scacheHashTablep = (cm_scache_t **) baseAddress;
         baseAddress += ComputeSizeOfSCacheHT(stats);
         cm_data.dnlcBaseAddress = (cm_nc_t *) baseAddress;
         baseAddress += ComputeSizeOfDNLCache();
-        cm_data.buf_hashTablepp = (cm_buf_t **) baseAddress;
-        baseAddress += ComputeSizeOfDataHT();
+        cm_data.buf_scacheHashTablepp = (cm_buf_t **) baseAddress;
+        baseAddress += ComputeSizeOfDataHT(cacheBlocks);
         cm_data.buf_fileHashTablepp = (cm_buf_t **) baseAddress;
-        baseAddress += ComputeSizeOfDataHT();
+        baseAddress += ComputeSizeOfDataHT(cacheBlocks);
         cm_data.bufHeaderBaseAddress = (cm_buf_t *) baseAddress;
         baseAddress += ComputeSizeOfDataHeaders(cacheBlocks);
         cm_data.bufDataBaseAddress = (char *) baseAddress;
-        baseAddress += ComputeSizeOfDataBuffers(cacheBlocks, CM_CONFIGDEFAULT_BLOCKSIZE);
+        baseAddress += ComputeSizeOfDataBuffers(cacheBlocks, blockSize);
         cm_data.bufEndOfData = (char *) baseAddress;
+	cm_data.buf_dirtyListp = NULL;
+	cm_data.buf_dirtyListEndp = NULL;
         cm_data.fakeDirVersion = 0x8;
         UuidCreate((UUID *)&cm_data.Uuid);
 	cm_data.volSerialNumber = volumeSerialNumber;
