@@ -22,7 +22,7 @@
  * SOFTWARE.
  */
 
-/* $Id: afsnewcreds.c,v 1.1.2.4 2007/05/05 21:14:48 jaltman Exp $ */
+/* $Id: afsnewcreds.c,v 1.1.2.6 2007/08/28 16:54:46 jaltman Exp $ */
 
 #include<afscred.h>
 #include<commctrl.h>
@@ -377,6 +377,7 @@ afs_remove_token_from_identities(wchar_t * cell) {
         khm_size cb;
         wchar_t vbuf[1024];
         wchar_t * tbuf = NULL;
+        khm_int32 enabled = 0;
 
         kcdb_identity_create(t, 0, &h_id);
         if (h_id == NULL) {
@@ -393,6 +394,10 @@ afs_remove_token_from_identities(wchar_t * cell) {
                                       0, &csp_afs)))
             goto _cleanup_loop;
 
+        if (KHM_SUCCEEDED(khc_read_int32(csp_afs, L"AFSEnabled", &enabled)) &&
+            !enabled)
+            goto _cleanup_loop;
+
         if (khc_read_multi_string(csp_afs, L"Cells", NULL, &cb)
             != KHM_ERROR_TOO_LONG)
             goto _cleanup_loop;
@@ -472,6 +477,7 @@ afs_check_add_token_to_identity(wchar_t * cell, khm_handle ident,
         khm_size cb;
         wchar_t vbuf[1024];
         wchar_t * tbuf = NULL;
+        khm_int32 enabled = 0;
 
         kcdb_identity_create(t, 0, &h_id);
         if (h_id == NULL) {
@@ -493,6 +499,10 @@ afs_check_add_token_to_identity(wchar_t * cell, khm_handle ident,
                                       0, &csp_afs)))
             goto _cleanup_loop;
 
+        if (KHM_SUCCEEDED(khc_read_int32(csp_afs, L"AFSEnabled", &enabled)) &&
+            !enabled)
+            goto _cleanup_loop;
+
         if (khc_read_multi_string(csp_afs, L"Cells", NULL, &cb)
             != KHM_ERROR_TOO_LONG)
             goto _cleanup_loop;
@@ -603,8 +613,8 @@ afs_cred_get_identity_creds(afs_cred_list * l,
         StringCbCopy(r->cell, cb, s);
 
         r->realm = NULL;
-        r->method = 0;
-        r->flags = 0;
+        r->method = AFS_TOKEN_AUTO;
+        r->flags = DLGROW_FLAG_CONFIG;
 
         if(KHM_SUCCEEDED(khc_open_space(h_cells, s, 
                                         0, &h_cell))) {
@@ -852,6 +862,9 @@ nc_dlg_show_tooltip(HWND hwnd,
 
     d = (afs_dlg_data *)(LONG_PTR) GetWindowLongPtr(hwnd, DWLP_USER);
 
+    if (d == NULL)
+        return;
+
     ZeroMemory(&ti, sizeof(ti));
     ti.cbSize = sizeof(ti);
     ti.hwnd = hwnd;
@@ -890,6 +903,9 @@ nc_dlg_hide_tooltip(HWND hwnd, UINT_PTR id)
 
     d = (afs_dlg_data *)(LONG_PTR) GetWindowLongPtr(hwnd, DWLP_USER);
 
+    if (d == NULL)
+        return;
+
     if(!d->tooltip_visible)
         return;
 
@@ -973,6 +989,9 @@ nc_dlg_del_token(HWND hwnd) {
 
     d = (afs_dlg_data *)(LONG_PTR) GetWindowLongPtr(hwnd, DWLP_USER);
 
+    if (d == NULL)
+        return;
+
     if (d->nc)
         khui_cw_find_type(d->nc, afs_credtype_id, &nct);
 
@@ -1059,6 +1078,9 @@ nc_dlg_add_token(HWND hwnd) {
 
     d = (afs_dlg_data *)(LONG_PTR) GetWindowLongPtr(hwnd, DWLP_USER);
 
+    if (d == NULL)
+        return;
+
     if (d->nc)
         khui_cw_find_type(d->nc, afs_credtype_id, &nct);
     else
@@ -1526,6 +1548,9 @@ afs_dlg_proc(HWND hwnd,
             d = (afs_dlg_data *)(LONG_PTR) 
                 GetWindowLongPtr(hwnd, DWLP_USER);
 
+            if (d == NULL)
+                return TRUE;
+
             EnterCriticalSection(&d->cs);
 
             if (d->nc) {
@@ -1540,6 +1565,8 @@ afs_dlg_proc(HWND hwnd,
             DeleteCriticalSection(&d->cs);
 
             PFREE(d);
+
+            SetWindowLongPtr(hwnd, DWLP_USER, 0);
         }
         return TRUE;
 
@@ -1551,6 +1578,9 @@ afs_dlg_proc(HWND hwnd,
             d = (afs_dlg_data *)(LONG_PTR) 
                 GetWindowLongPtr(hwnd, DWLP_USER);
 
+            if (d == NULL)
+                return FALSE;
+
             EnterCriticalSection(&d->cs);
 
             if (d->nc)
@@ -1605,6 +1635,9 @@ afs_dlg_proc(HWND hwnd,
             d = (afs_dlg_data *)(LONG_PTR) 
                 GetWindowLongPtr(hwnd, DWLP_USER);
 
+            if (d == NULL)
+                return TRUE;
+
             EnterCriticalSection(&d->cs);
 
             if (d->nc)
@@ -1658,7 +1691,7 @@ afs_dlg_proc(HWND hwnd,
                             }
                             SendDlgItemMessage(hwnd, IDC_NCAFS_CELL, 
                                                CB_SELECTSTRING, 
-                                               -1, (LPARAM) wbuf);
+                                               (WPARAM)-1, (LPARAM) wbuf);
                         }
                     }
 
@@ -1682,7 +1715,7 @@ afs_dlg_proc(HWND hwnd,
                                            CB_SETITEMDATA, idx, TRUE);
                         SendDlgItemMessage(hwnd, IDC_NCAFS_REALM, 
                                            CB_SELECTSTRING, 
-                                           -1, (LPARAM) wbuf);
+                                           (WPARAM)-1, (LPARAM) wbuf);
                     }
 
                     /* load the LRU realms */
@@ -1701,7 +1734,8 @@ afs_dlg_proc(HWND hwnd,
                             s = buf;
                             while(*s) {
                                 if(SendDlgItemMessage(hwnd, IDC_NCAFS_REALM, 
-                                                      CB_FINDSTRINGEXACT, -1, 
+                                                      CB_FINDSTRINGEXACT, 
+                                                      (WPARAM)-1,
                                                       (LPARAM) s) == CB_ERR) {
                                     idx = 
                                         (int)
@@ -1885,6 +1919,9 @@ afs_dlg_proc(HWND hwnd,
                 d = (afs_dlg_data *)(LONG_PTR) 
                     GetWindowLongPtr(hwnd, DWLP_USER);
 
+                if (d == NULL)
+                    return FALSE;
+
                 EnterCriticalSection(&d->cs);
 
                 hw = GetDlgItem(hwnd, IDC_NCAFS_TOKENLIST);
@@ -1916,7 +1953,8 @@ afs_dlg_proc(HWND hwnd,
                     LoadString(hResModule, IDS_NC_REALM_AUTO, wbuf, 
                                ARRAYLENGTH(wbuf));
                     idx = (int) SendDlgItemMessage(hwnd, IDC_NCAFS_REALM, 
-                                                   CB_FINDSTRINGEXACT, -1, 
+                                                   CB_FINDSTRINGEXACT, 
+                                                   (WPARAM) -1,
                                                    (LPARAM) wbuf);
                     SendDlgItemMessage(hwnd, IDC_NCAFS_REALM, CB_SETCURSEL,
                                        idx, 0);
@@ -1939,6 +1977,9 @@ afs_dlg_proc(HWND hwnd,
                 d = (afs_dlg_data *)(LONG_PTR) 
                     GetWindowLongPtr(hwnd, DWLP_USER);
 
+                if (d == NULL)
+                    return FALSE;
+
                 EnterCriticalSection(&d->cs);
 
                 pnmi = (LPNMITEMACTIVATE) lpnmh;
@@ -2070,13 +2111,13 @@ afs_adjust_token_ident_proc(khm_handle cred, void * vd)
             kcdb_cred_set_identity(cred, b->ident);
             if(l->rows[i].realm)
                 kcdb_cred_set_attr(cred, afs_attr_realm, l->rows[i].realm, 
-                                   KCDB_CBSIZE_AUTO);
+                                   (khm_size)KCDB_CBSIZE_AUTO);
             else
                 kcdb_cred_set_attr(cred, afs_attr_realm, NULL, 0);
 
             method = l->rows[i].method;
             kcdb_cred_set_attr(cred, afs_attr_method, &method, 
-                               KCDB_CBSIZE_AUTO);
+                               (khm_size)KCDB_CBSIZE_AUTO);
 
             break;
         }
@@ -2158,13 +2199,13 @@ afs_cred_write_ident_data(afs_dlg_data * d) {
                               lru_cell,
                               &cbt);
     } else {
-        cbcell = MAXCELLCHARS * sizeof(wchar_t) * 
-            l->n_rows;
-        if (cbcell > 0) {
+        cbcell = MAXCELLCHARS * sizeof(wchar_t) * l->n_rows + sizeof(wchar_t);
+        if (l->n_rows > 0) {
             lru_cell = PMALLOC(cbcell);
             ZeroMemory(lru_cell, cbcell);
         } else {
             lru_cell = NULL;
+            cbcell = 0;
         }
     }
 
@@ -2182,21 +2223,23 @@ afs_cred_write_ident_data(afs_dlg_data * d) {
                               lru_realm,
                               &cbt);
     } else {
-        cbrealm = MAXCELLCHARS * sizeof(wchar_t) * l->n_rows;
-        if (cbrealm > 0) {
+        cbrealm = MAXCELLCHARS * sizeof(wchar_t) * l->n_rows + sizeof(wchar_t);
+        if (l->n_rows > 0) {
             lru_realm = PMALLOC(cbrealm);
             ZeroMemory(lru_realm, cbrealm);
         } else {
             lru_cell = NULL;
+            cbrealm = 0;
         }
     }
 
-    cbidcell = MAXCELLCHARS * sizeof(wchar_t) * l->n_rows;
-    if (cbidcell > 0) {
+    cbidcell = MAXCELLCHARS * sizeof(wchar_t) * l->n_rows + sizeof(wchar_t);
+    if (l->n_rows > 0) {
         id_cell = PMALLOC(cbidcell);
         ZeroMemory(id_cell, cbidcell);
     } else {
         id_cell = NULL;
+        cbidcell = 0;
     }
 
     for(i=0; i < l->n_rows; i++)
@@ -2244,10 +2287,12 @@ afs_cred_write_ident_data(afs_dlg_data * d) {
                 khc_close_space(h_acell);
             }
 
-            if (h_cellmap) {
-                khc_write_string(h_cellmap,
-                                 l->rows[i].cell,
-                                 idname);
+            if (l->rows[i].flags & DLGROW_FLAG_DONE) {
+                if (h_cellmap) {
+                    khc_write_string(h_cellmap,
+                                     l->rows[i].cell,
+                                     idname);
+                }
             }
         }
 
@@ -2260,6 +2305,8 @@ afs_cred_write_ident_data(afs_dlg_data * d) {
     if (id_cell)
         khc_write_multi_string(h_afs, L"Cells",
                                id_cell);
+    else
+        khc_write_multi_string(h_afs, L"Cells", L"\0");
 
     if (d->config_dlg) {
         if (d->dirty)
