@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/butc/dump.c,v 1.15 2003/11/23 04:53:31 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/butc/dump.c,v 1.18 2005/04/03 18:09:26 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -59,15 +59,13 @@ addVolume();
 
 extern struct rx_connection *UV_Bind();
 
-extern char *globalCellName;
-
-extern afs_int32 xbsaType;
 extern afs_int32 groupId;
 extern afs_int32 BufferSize;
 extern afs_int32 statusSize;
 extern FILE *centralLogIO;
 afs_int32 lastPass = 0;
 #ifdef xbsa
+extern afs_int32 xbsaType;
 char *butcdumpIdStr = "/backup_afs_volume_dumps";
 extern struct butx_transactionInfo butxInfo;
 extern char *xbsaObjectOwner;
@@ -108,6 +106,7 @@ int
 localtime_r(time_t * t, struct tm *tm)
 {
     memcpy(tm, localtime(t), sizeof(struct tm));
+    return 0;
 }
 #endif
 
@@ -145,7 +144,7 @@ extern int maxpass;
 
 afs_int32 tc_EndMargin;
 afs_int32 tc_KEndMargin;
-char *bufferBlock;
+static char *bufferBlock;
 
 /* compute the absolute expiration date */
 afs_int32
@@ -823,14 +822,12 @@ xbsaDumpVolume(struct tc_dumpDesc * curDump, struct dumpRock * dparamsPtr)
   abort_exit:
     dparamsPtr->curVolumeStatus = DUMP_FAILED;
     ERROR_EXIT(code);
+#else
+    return 0;
 #endif
 }
 
-#ifdef AFS_DEC_ENV
-#define HOSTADDR(sockaddr) (sockaddr)->sin_addr.S_un.S_addr
-#else
 #define HOSTADDR(sockaddr) (sockaddr)->sin_addr.s_addr
-#endif
 
 /* dumpPass
  *	Go through the list of volumes to dump, dumping each one. The action
@@ -1461,6 +1458,7 @@ printTapeLabel(struct butm_tapeLabel *tl)
     printf("   pName          = %s\n", tl->pName);
     printf("   size           = %u\n", tl->size);
     printf("   dumpPath       = %s\n", tl->dumpPath);
+    return 0;
 }
 
 /* getXBSATape
@@ -1902,6 +1900,7 @@ volumeHeader_hton(struct volumeHeader *hostPtr, struct volumeHeader *netPtr)
     volHdr.cloneDate = htonl(hostPtr->cloneDate);
 
     memcpy(netPtr, &volHdr, sizeof(struct volumeHeader));
+    return 0;
 }
 
 /* database related routines */
